<template>
  <LoadingLayout :loading="state.loading">
    <AppContainer>
      <ProTableQueryFilterBar @on-reset="reset">
        <template #query>
          <QueryFilterItem tip-content="最近申报日期">
            <FieldDatePicker
              v-model="extraParamState.lastApplyTime"
              type="daterange"
              range-separator="~"
              start-placeholder="开始日期"
              end-placeholder="结束日期"
              clearable
              @change="getList()"
            ></FieldDatePicker>
          </QueryFilterItem>
          <QueryFilterItem tip-content="最近拨付日期">
            <FieldDatePicker
              v-model="extraParamState.lastPayTime"
              type="daterange"
              range-separator="~"
              start-placeholder="开始日期"
              end-placeholder="结束日期"
              clearable
              @change="getList()"
            ></FieldDatePicker>
          </QueryFilterItem>
          <QueryFilterItem tip-content="最近充值日期">
            <FieldDatePicker
              v-model="extraParamState.lastSettleTime"
              type="daterange"
              range-separator="~"
              start-placeholder="开始日期"
              end-placeholder="结束日期"
              clearable
              @change="getList()"
            ></FieldDatePicker>
          </QueryFilterItem>
          <QueryFilterItem>
            <SearchInput
              v-model="extraParamState.keywords"
              style="width: 300px"
              placeholder="企业名/统一信用代码"
              @on-click-search="getList"
            >
            </SearchInput>
          </QueryFilterItem>
        </template>
      </ProTableQueryFilterBar>

      <ProTableV2 v-bind="proTableProps" :columns="column" :operationBtns="operationBtns">
      </ProTableV2>
    </AppContainer>
  </LoadingLayout>
</template>

<script setup lang="ts">
import {
  LoadingLayout,
  AppContainer,
  useTable,
  ProTableQueryFilterBar,
  ProTableV2,
  defineOperationBtns,
  SearchInput,
  QueryFilterItem,
  FieldDatePicker,
} from '@bole-core/components';
import { OrderInputType } from '@bole-core/core';
import { format } from '@/utils';
import * as parkBountyApplyServices from '@/services/api/ParkBountyApply';
import _ from 'lodash';
import { ModelValueType } from 'element-plus';
import { EnterpriseTypeText } from '@/constants';

defineOptions({
  name: 'EnterpriseInfo',
});

const column: API.CustomModuleColumnDto[] = [
  {
    id: '1',
    enCode: 'enterpriseName',
    name: '企业名',
    width: 250,
  },
  {
    id: '2',
    enCode: 'societyCreditCode',
    name: '统一社会信用代码',
    width: 200,
  },
  {
    id: '3',
    enCode: 'enterpriseType',
    name: '企业类型',
    width: 150,
  },
  {
    id: '4',
    enCode: 'industrialParkName',
    name: '所属园区',
    width: 200,
  },
  {
    id: '5',
    enCode: 'parkTypName',
    name: '园区类型',
    width: 150,
  },
  {
    id: '6',
    enCode: 'applyCount',
    name: '申报次数',
    width: 150,
  },
  {
    id: '7',
    enCode: 'lastApplyTime',
    name: '最近申报日期',
    width: 180,
  },
  {
    id: '8',
    enCode: 'financeCount',
    name: '财政拨付次数',
    width: 150,
  },
  {
    id: '9',
    enCode: 'lastFinanceTime',
    name: '最近拨付日期',
    width: 180,
  },
  {
    id: '10',
    enCode: 'financeSumAmount',
    name: '拨付总额',
    width: 150,
  },
  {
    id: '11',
    enCode: 'settleCount',
    name: '平台充值次数',
    width: 150,
  },
  {
    id: '12',
    enCode: 'lastSettleTime',
    name: '最近充值日期',
    width: 180,
  },
  {
    id: '13',
    enCode: 'settleSumAmount',
    name: '充值总额',
    width: 150,
  },
  {
    id: '14',
    enCode: 'bountyAmount',
    name: '平台充值余额',
    width: 150,
  },
];

const operationBtns = defineOperationBtns([
  {
    data: {
      enCode: 'detailBtn',
      name: '详情',
    },
    emits: {
      onClick: (role) => goDetail(role),
    },
  },
]);

const router = useRouter();
const BaseState = {
  loading: true,
};

const state = reactive({ ...BaseState });

onMounted(async () => {
  await getList();
  state.loading = false;
});

const {
  getDataSource: getList,
  proTableProps,
  paginationState,
  extraParamState,
  reset,
} = useTable(
  async ({ pageIndex, pageSize }, extraParamState) => {
    try {
      let params: API.QueryParkCustomerManageInput = {
        pageModel: {
          rows: pageSize,
          page: pageIndex,
          orderInput: extraParamState.orderInput,
        },
        keywords: extraParamState.keywords,
        lastApplyBeginTime: format(extraParamState.lastApplyTime?.[0] ?? '', 'YYYY-MM-DD 00:00:00'),
        lastApplyEndTime: format(extraParamState.lastApplyTime?.[1] ?? '', 'YYYY-MM-DD 23:59:59'),
        lastPayBeginTime: format(extraParamState.lastPayTime?.[0] ?? '', 'YYYY-MM-DD 00:00:00'),
        lastPayEndTime: format(extraParamState.lastPayTime?.[1] ?? '', 'YYYY-MM-DD 23:59:59'),
        lastSettleBeginTime: format(
          extraParamState.lastSettleTime?.[0] ?? '',
          'YYYY-MM-DD 00:00:00'
        ),
        lastSettleEndTime: format(extraParamState.lastSettleTime?.[1] ?? '', 'YYYY-MM-DD 23:59:59'),
      };
      let res = await parkBountyApplyServices.getParkCustomerManagePage(params, {
        showLoading: !state.loading,
      });
      return res;
    } catch (error) {}
  },
  {
    defaultExtraParams: {
      keywords: '',
      lastApplyTime: [] as unknown as ModelValueType,
      lastPayTime: [] as unknown as ModelValueType,
      lastSettleTime: [] as unknown as ModelValueType,
      orderInput: [{ property: 'id', order: OrderInputType.Desc }],
    },
    columnsRenderProps: {
      lastApplyTime: { type: 'date', format: 'YYYY-MM-DD HH:mm:ss' },
      lastFinanceTime: { type: 'date', format: 'YYYY-MM-DD HH:mm:ss' },
      financeSumAmount: { type: 'money' },
      lastSettleTime: { type: 'date', format: 'YYYY-MM-DD HH:mm:ss' },
      settleSumAmount: { type: 'money' },
      bountyAmount: { type: 'money' },
      enterpriseType: { type: 'enum', valueEnum: EnterpriseTypeText },
    },
  }
);

function goDetail(row: API.GetParkCustomerManageOutput) {
  router.push({
    name: 'EnterpriseInfoDetail',
    params: {
      id: row.id,
    },
  });
}
</script>

<style lang="scss" scoped>
@use '@/style/common.scss' as *;
</style>
